#
# spec file for package clapper
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define typelib  typelib-1_0-GstClapper-1
%define libname  libgstclapper-1_0-0
%define libname2 libgstclapperglbaseimporter0
%define appname  com.github.rafostar.Clapper

Name:           clapper
Version:        0.5.2
Release:        1.6
Summary:        A GNOME media player built using GJS with GTK4
License:        GPL-3.0-or-later
URL:            https://github.com/Rafostar/clapper
Source:         %{url}/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires:  Mesa-libEGL-devel
BuildRequires:  Mesa-libGL-devel
BuildRequires:  Mesa-libGLESv2-devel
BuildRequires:  Mesa-libGLESv3-devel
BuildRequires:  c++_compiler
BuildRequires:  c_compiler
BuildRequires:  desktop-file-utils
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gjs-1.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.18.0
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)

%description
A GNOME media player built using GJS with GTK4 toolkit and powered by GStreamer with OpenGL rendering.

%package devel
Summary:        Development files for %{name}
Requires:       %{libname2} = %{version}
Requires:       %{libname} = %{version}
Requires:       %{typelib} = %{version}

%description devel
%{summary}.

%package -n %{typelib}
Summary:        Clapper library typelib

%description -n %{typelib}
%{summary}.

%package -n %{libname}
Summary:        Library for %{name}
Obsoletes:      libgstclapper-1 < 0.5
Provides:       libgstclapper-1 = 0.5

%description -n %{libname}
%{summary}.

%package -n %{libname2}
Summary:        Library for %{name}

%description -n %{libname2}
%{summary}.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install

%find_lang %{appname}

%ldconfig_scriptlets -n %{libname}
%ldconfig_scriptlets -n %{libname2}

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/%{appname}.desktop

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_bindir}/%{appname}
%{_datadir}/%{appname}/
%{_datadir}/glib-2.0/schemas/%{appname}.gschema.xml
%{_datadir}/icons/hicolor/*/*/*.svg
%{_datadir}/metainfo/%{appname}.metainfo.xml
%{_datadir}/mime/packages/%{appname}.xml
%{_datadir}/applications/%{appname}.desktop
%{_datadir}/dbus-1/services/%{appname}.service
%dir %{_libdir}/clapper-1.0
%dir %{_libdir}/clapper-1.0/gst
%dir %{_libdir}/clapper-1.0/gst/plugin
%dir %{_libdir}/clapper-1.0/gst/plugin/importers
%{_libdir}/clapper-1.0/gst/plugin/importers/*.so
%dir %{_libdir}/gstreamer-1.0
%{_libdir}/gstreamer-1.0/*.so

%files -n %{libname}
%dir %{_libdir}/%{appname}
%{_libdir}/%{appname}/*.so.*

%files -n %{libname2}
%{_libdir}/libgstclapperglbaseimporter.so.*

%files -n %{typelib}
%dir %{_libdir}/%{appname}/girepository-1.0
%{_libdir}/%{appname}/girepository-1.0/GstClapper-1.0.typelib

%files devel
%{_libdir}/%{appname}/*.so
%{_libdir}/*.so
%{_datadir}/gir-1.0/GstClapper-1.0.gir

%files lang -f %{appname}.lang

%changelog
* Fri Aug 26 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.5.2:
  + Fix time labels display on RTL languages
  + Improved GL/GLES context automatic selection
  + Updated translations.
* Thu Jun  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.5.1:
  * A quick hotfix release. Fixes problems with new video sink on
    displays with non-100%% scaling applied.
- Changes from version 0.5.0:
  * Clapper now includes an all new and improved GStreamer video
    sink. With it, we are moving away from GLArea into using
    GdkPaintable. This already gives us slight performance
    improvement in some cases and opens new possibilities to
    improve it further at a later time. New sink now also handles
    overlaying and displaying subtitles on the GTK side of things
    (as a separate GdkTextures instead of drawing them into
    framebuffer). Old, now called "legacy" sink is still included.
    If there are any problems with the new one, you can set
    CLAPPER_USE_LEGACY_SINK=1 env to use the old one.
  * Networking was ported into libsoup3. The built-in, unfinished
    web application was removed.
  * Additionally, app now supports D-Bus launching
    (DBusActivatable).
  * Some other misc fixes and few small UI changes were also done.
  * Updated translations.
- Update libnames define to align with soname.
* Sat Feb 26 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.4.1:
  * Compatibility with more recent libadwaita versions
  * Toggle mute with M button alone
  * Allow handling YouTube with external GStreamer plugins
  * Fix catching errors when reading clipboard
  * Fix missing translator-credits
  * Fix missing gio-unix-2.0 dep
  * Fix playback pausing when entering fullscreen with touchscreen
  * Fix GST_PLUGIN_FEATURE_RANK env usage
  * Fix video/audio decoder change detection
  * Merge global video tags instead replacing them
  * Few other misc bug fixes
  * Updated translations.
* Mon Oct  4 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Fix typelib name to follow standard in openSUSE.
* Mon Sep 13 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.4.0:
  * New and adaptive preferences window.
  * Improved open URI dialog.
  * Few small tweaks to fullscreen UI design.
  * Show current video and audio decoders in popovers
    (easy way to check if HW accel is used).
  * Enabled NVDEC hardware acceleration by default
    (requires Nvidia proprietary drivers).
  * Added option to use PipeWire for audio output (experimental).
  * Added option to use playbin3 element (experimental).
  * Improved performance on devices running OpenGL ES.
  * Translations support.
  * New keyboard shortcuts:
  - Leave fullscreen with Escape key.
  - Toggle mute with Ctrl+M.
  * More touchscreen gestures:
  - Toggle playback with a long press.
  - Switch playlist items via double tap on screen side.
  * New translations:
  - Catalan.
  - Dutch.
  - German.
  - Italian.
  - Polish.
* Fri Jun 18 2021 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 0.3.0:
  * Added MPRIS support.
  * Added repeat modes: single video, whole playlist and shuffle.
  * Support opening folders with media files.
  * Append playlist items by holding Ctrl while doing Drag and Drop.
  * Improved handling of keyboard shortcuts.
  * Added more keyboard shortcuts.
  * Added window that shows available keyboard shortcuts.
  * Show black screen by default after playback
    (make showing last frame optional instead).
  * Added ability to export playlist to file.
  * Improve handling of changing displays with different resolutions.
  * Added support for EGL under x11 with GTK 4.3.1 or later.
  * Added missing symbolic app icon.
  * Some misc bug fixes and code cleanups.
* Mon Apr 19 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.2.1:
  * Fix missing top left menu buttons on some system configurations
  * Fix potential video sink deadlock
  * Do not show mobile controls transition on launch
  * Show tooltip with full playlist item text on hover
  * Auto select best matching resolution for used monitor
  * Added some YouTube related preferences
  * Added support for live HLS videos
  * Added support for non-adaptive live HLS streaming
* Fri Feb 26 2021 Dead Mozay <dead_mozay@opensuse.org>
- Initial package.
